View source: R/reset_comparison_settings.R
| reset_comparison_settings | R Documentation |
Resets all comparison settings back to their defaults, clearing any custom tolerance or other parameters.
reset_comparison_settings()
Invisible NULL. Called for its side effect of resetting package settings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.