set_tolerance: Set Tolerance Level for Comparisons

View source: R/set_tolerance.R

set_toleranceR Documentation

Set Tolerance Level for Comparisons

Description

Sets the numeric tolerance for floating-point comparisons, allowing small differences within the tolerance to be treated as equal.

Usage

set_tolerance(tolerance = 0)

Arguments

tolerance

A non-negative numeric value specifying the tolerance level.

Value

Invisible NULL. Called for its side effect of updating the tolerance setting.


clinCompare documentation built on Feb. 19, 2026, 1:07 a.m.