transform_variables: Transform Variables in a Dataset

View source: R/transform_variables.R

transform_variablesR Documentation

Transform Variables in a Dataset

Description

Applies mathematical or logical transformations to specified columns in a data frame based on a named list of transformation functions.

Usage

transform_variables(df, transformations)

Arguments

df

A data frame containing the variables to be transformed.

transformations

A list of functions for transforming the variables. The names of the list should correspond to the variable names in the dataset.

Value

A data frame with transformed variables.


clinCompare documentation built on Feb. 19, 2026, 1:07 a.m.