View source: R/generate_detailed_report.R
| generate_detailed_report | R Documentation |
Creates a detailed report outlining all the differences found in the comparison, including variable differences, observation differences, and group-based discrepancies.
generate_detailed_report(
comparison_results,
output_format = "text",
file_name = NULL
)
comparison_results |
A list containing the results of dataset comparisons. |
output_format |
Format of the output ('text' or 'html'). |
file_name |
Name of the file to save the report to (applicable for 'html' format). |
The detailed report. For 'text', prints to console. For 'html', writes to file.
## Not run:
generate_detailed_report(comparison_results, output_format = "text")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.