Learn R Programming

clinCompare (version 1.0.0)

generate_detailed_report: Generate a Detailed Report of Dataset Comparison

Description

Creates a detailed report outlining all the differences found in the comparison, including variable differences, observation differences, and group-based discrepancies.

Usage

generate_detailed_report(
  comparison_results,
  output_format = "text",
  file_name = NULL
)

Value

The detailed report. For 'text', prints to console. For 'html', writes to file.

Arguments

comparison_results

A list containing the results of dataset comparisons.

output_format

Format of the output ('text' or 'html').

file_name

Name of the file to save the report to (applicable for 'html' format).

Examples

Run this code
if (FALSE) {
  generate_detailed_report(comparison_results, output_format = "text")
}

Run the code above in your browser using DataLab