View source: R/generate_summary_report.R
| generate_summary_report | R Documentation |
Provides a summary of the comparison results, highlighting key points such as the number of differing observations and variables.
generate_summary_report(
comparison_results,
detail_level = "high",
output_format = "text",
file_name = NULL
)
comparison_results |
A list containing the results of dataset comparisons. |
detail_level |
The level of detail ('high', 'medium', 'low') for the summary. |
output_format |
Format of the output ('text' or 'html'). |
file_name |
Name of the file to save the report to (applicable for 'html' format). |
The summary report. For 'text', prints to console. For 'html', writes to file.
## Not run:
generate_summary_report(comparison_results, detail_level = "high", output_format = "text")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.