Learn R Programming

clinCompare (version 1.0.0)

generate_summary_report: Generate a Summary Report of Dataset Comparison

Description

Provides a summary of the comparison results, highlighting key points such as the number of differing observations and variables.

Usage

generate_summary_report(
  comparison_results,
  detail_level = "high",
  output_format = "text",
  file_name = NULL
)

Value

The summary report. For 'text', prints to console. For 'html', writes to file.

Arguments

comparison_results

A list containing the results of dataset comparisons.

detail_level

The level of detail ('high', 'medium', 'low') for the summary.

output_format

Format of the output ('text' or 'html').

file_name

Name of the file to save the report to (applicable for 'html' format).

Examples

Run this code
if (FALSE) {
  generate_summary_report(comparison_results, detail_level = "high", output_format = "text")
}

Run the code above in your browser using DataLab