powered by
Provides a summary of the comparison results, highlighting key points such as the number of differing observations and variables.
generate_summary_report( comparison_results, detail_level = "high", output_format = "text", file_name = NULL )
The summary report. For 'text', prints to console. For 'html', writes to file.
A list containing the results of dataset comparisons.
The level of detail ('high', 'medium', 'low') for the summary.
Format of the output ('text' or 'html').
Name of the file to save the report to (applicable for 'html' format).
if (FALSE) { generate_summary_report(comparison_results, detail_level = "high", output_format = "text") }
Run the code above in your browser using DataLab