View source: R/report_differences.R
| report_differences | R Documentation |
Creates a formatted report summarizing all differences found between two data frames, including column-level and value-level differences.
report_differences(variable_diffs, observation_diffs)
variable_diffs |
A data frame or list detailing the differences found in variables. |
observation_diffs |
A data frame or list detailing the differences found in observations. |
A structured report of the differences, typically a list or a data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.