Learn R Programming

clinCompare (version 1.0.0)

set_tolerance: Set Tolerance Level for Comparisons

Description

Sets the numeric tolerance for floating-point comparisons, allowing small differences within the tolerance to be treated as equal.

Usage

set_tolerance(tolerance = 0)

Value

Invisible NULL. Called for its side effect of updating the tolerance setting.

Arguments

tolerance

A non-negative numeric value specifying the tolerance level.