View source: R/transform_variables.R
| transform_variables | R Documentation |
Applies mathematical or logical transformations to specified columns in a data frame based on a named list of transformation functions.
transform_variables(df, transformations)
df |
A data frame containing the variables to be transformed. |
transformations |
A list of functions for transforming the variables. The names of the list should correspond to the variable names in the dataset. |
A data frame with transformed variables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.