Applies mathematical or logical transformations to specified columns in a data frame based on a named list of transformation functions.
transform_variables(df, transformations)A data frame with transformed variables.
A data frame containing the variables to be transformed.
A list of functions for transforming the variables. The names of the list should correspond to the variable names in the dataset.